function [MTX_new]=countryID_v2_fn(allLVAdata)
%       figs ==1, if want to see figures
%Converts European Article numbers (EAN) into a country code vector and
%adds the vector as columns 9 to the original data matrix.
%
%The addition to countryID.m in this counryID_v2.m is that we use domestic/
%import info from product tree to label origin of some 'store items'.
%   column 9:       countryID vector (loose 0.1% of data)

load ../Data/WBcodes %+OTH=999;INT=100;INT_home=101;INT_foreign=102
MTX=allLVAdata;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Basic diagnostics
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

EANlist=num2str(MTX(:,8),'%-.0f');%convert whole number part to string
EANdigit=nan(size(MTX,1),1);
for s=1:size(MTX,1)
   EANdigit(s)=length(num2str(MTX(s,8),'%-.0f')); %# of digits in each EAN
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate countryID vector: Approach 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%modify EANlist
EANlist1=EANlist;
EANlist2=EANlist;
clear EANlist;
tempinx1_7=find(EANdigit<8);
for i=tempinx1_7'
    EANlist1(i,:)='00000000000000';
end
tempinx8=find(EANdigit==8);
for i=tempinx8'
    EANlist1(i,1:13)=strcat(EANlist1(i,:),'00000');
end
tempinx9_10=find(EANdigit>8&EANdigit<11);
for i=tempinx9_10'
    %need this if...elseif, becase for HD size of EANlist is 13, not 14
    if size(EANlist1,2)==14
        EANlist1(i,:)='00000000000000';
    elseif size(EANlist1,2)==13
        EANlist1(i,:)='0000000000000';
    end
end
tempinx11=find(EANdigit==11);
for i=tempinx11'
    EANlist1(i,1:13)=strcat('00',EANlist1(i,:));
end
%special 12-digit case: 1001200xxxxx --> 200xxxxx00000
tempinx12_SC=find(EANdigit==12&str2num(EANlist1(:,1:7))==1001200);
for i=tempinx12_SC'
    EANlist1(i,1:13)=strcat(EANlist1(i,5:12),'00000');
end
%all other 12-dig cases
tempinx12=setdiff(find(EANdigit==12),tempinx12_SC);
for i=tempinx12'
    EANlist1(i,1:13)=strcat('0',EANlist1(i,:));
end
tempinx13=find(EANdigit==13);%do nothing
tempinx14=find(EANdigit==14);
for i=tempinx14'
    EANlist1(i,:)='00000000000000';
end

%isolate 1st 3 digits
Clist1=str2num(EANlist1(:,1:3));

%assign country codes using WB definitions +
%       store products:        100,INT
%       unassigned countries:  999,OTH
ccode1=nan(length(EANlist1),1);
ccode1(ismember(Clist1,[20:29 40:49 200:299]))=100; %INT
ccode1(ismember(Clist1,[1:19 30:39 60:139]))=111; %USA
ccode1(ismember(Clist1,300:379))=132; %FRA
ccode1(ismember(Clist1,400:440))=134; %DEU
ccode1(ismember(Clist1,[450:459 490:499]))=158; %JPN
ccode1(ismember(Clist1,460:469))=922; %RUS
ccode1(ismember(Clist1,500:509))=112; %GBR
ccode1(ismember(Clist1,520:521))=174; %GRC
ccode1(ismember(Clist1,540:549))=124; %BEL
ccode1(ismember(Clist1,570:579))=128; %DNK
ccode1(ismember(Clist1,600:601))=199; %ZAF
ccode1(ismember(Clist1,640:649))=172; %FIN
ccode1(ismember(Clist1,690:695))=924; %CHN
ccode1(ismember(Clist1,700:709))=142; %NOR
ccode1(ismember(Clist1,730:739))=144; %SWE
ccode1(ismember(Clist1,754:755))=156; %CAN
ccode1(ismember(Clist1,760:769))=146; %CHE
ccode1(ismember(Clist1,770:771))=233; %COL
ccode1(ismember(Clist1,778:779))=213; %ARG
ccode1(ismember(Clist1,789:790))=223; %BRA
ccode1(ismember(Clist1,800:839))=136; %ITA
ccode1(ismember(Clist1,840:849))=184; %ESP
ccode1(ismember(Clist1,868:869))=186; %TUR
ccode1(ismember(Clist1,870:879))=138; %NLD
ccode1(ismember(Clist1,900:919))=122; %AUT
ccode1(ismember(Clist1,930:939))=193; %AUS
ccode1(ismember(Clist1,940:949))=196; %NZL
ccode1(Clist1==380)=918; %BGR
ccode1(Clist1==383)=961; %SVN
ccode1(Clist1==474)=939; %EST
ccode1(Clist1==475)=941; %LVA
ccode1(Clist1==477)=946; %LTU
ccode1(Clist1==481)=913; %BLR
ccode1(Clist1==482)=926; %UKR
ccode1(Clist1==539)=178; %IRL
ccode1(Clist1==560)=182; %PRT
ccode1(Clist1==569)=176; %ISL
ccode1(Clist1==590)=964; %POL
ccode1(Clist1==594)=968; %ROM
ccode1(Clist1==599)=944; %HUN
ccode1(Clist1==858)=936; %SVK
ccode1(Clist1==859)=935; %CZE
ccode1(Clist1==880)=542; %KOR
other=[385 387 389 470 471 476 478:480 484:489 528:531 535 603 604 608 ...
    609 611 613 615 616 618 619 621 622 624:629 729 740:746 750 759 ...
    773 775 777 780 784 786 850 860 865 867 884 885 888 890 893 896 899 ...
    955 958];
ccode1(ismember(Clist1,other))=999; %OTH

MTX_new=[MTX(:,1:8) ccode1 MTX(:,9:end)];