%This code generates data for regressions and quantification exercise in 
%Figures 14-15.
%
%Collect data for each of 19 [t-->t+1] comparisons of quarterly data for 
%scanner items that exist in both periods.
%
% Data is collected in matrixes of size Nx19, were N>=max number of obs in 
% any period period. N=25000 is sufficient. Output matrixes are:
% (i)   Expenditures on each item in t and t+1 (Ri1 and Ri2)
% (ii)  UVs of each item in t and t+1 (Pi1 and Pi2)
% (iii) Quantities of each item in t and t+1 (Qi1 and Qi2)
% (iv)  Matix with corresponding product group information (GRP)
% (v)   Matix with corresponding information about origin (ORG)
% (vi)  Matix with corresponding UPC code (ITM)
% (vii) Matrix with corresponding store code (STR)
% (viii)Matrix with corresponding info about total expenditures on the
%        product group in t and t+1 (Rg1 and Rg2)
% (ix)  Matrix with cooresponding inflation rate for the product group
%        betweeen t and t+1 (dPg)
% (x)   Matrix with corresponding item withing-group relative price (QUALi)
% (xi)  Matrix with corresponding product groups expenditure share in total 
%        expenditures in t and t+1 (Sg1 ans Sg2)
% (xii) Matrix with corresponding q-o-q change in HH real per capita
%        consumption (d_C)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
%load data
load ../Data/dataAER_RR allLVAdata_dropIN_4secUV

%choose product level
prodlev=4;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
MTX=allLVAdata_drop_trim_4secUV;
hs=9;
obs=(size(MTX,2)-hs)/2;
maxobs=25000; %max obs per period
MTX(:,2)=floor(MTX(:,2)/(10^(4-prodlev)));
seclist=unique(MTX(:,2));
G=length(seclist);
N=size(MTX,1);
Q=MTX(:,hs+1:hs+obs);
P=MTX(:,hs+obs+1:hs+2*obs);

load ../Data/PandQdata_4secUV
m=0;
j=0.1*10^prodlev:floor(0.999999*10^prodlev);
DATAMTX=DATAMTX(DATAMTX(:,3)==m,:);
DATAMTXsum=DATAMTXsum(DATAMTXsum(:,2)==m,:);
DATAMTX=DATAMTX(ismember(DATAMTX(:,2),j),:);
DATAMTXsum=DATAMTXsum(ismember(DATAMTXsum(:,1),j),:);

for i=1:G
    temp=MTX(ismember(MTX(:,2),seclist(i)),:);
    Qtemp=temp(:,hs+2:hs+obs)-temp(:,hs+1:hs+obs-1);
    Ptemp=DATAMTX(DATAMTX(:,2)==seclist(i),4)';
    Ptemp=exp(cumsum([1 Ptemp(2:end)],2));
    Ptemp=repmat(Ptemp(2:end),size(Qtemp,1),1);
    temp3=~isnan(Qtemp.*Ptemp);
    obs_cnt(i,1)=sum(sum(temp3));
    item_cnt(i,1)=sum(sum(temp3,2)>0);
end
DATAMTXsum(:,13:14)=[obs_cnt item_cnt];

%prepare data
MTX=MTX(ismember(MTX(:,2),seclist),:);
KEEP=sum(DATAMTXsum(ismember(DATAMTXsum(:,1),seclist),3));
G=length(seclist);
N=size(MTX,1);
Q=MTX(:,hs+1:hs+obs);
P=MTX(:,hs+obs+1:hs+2*obs);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%define data matrixes
Ri1=nan(maxobs,19);
Ri2=nan(maxobs,19);
Pi1=nan(maxobs,19);
Pi2=nan(maxobs,19);
Qi1=nan(maxobs,19);
Qi2=nan(maxobs,19);
GRP=nan(maxobs,19);
ORG=nan(maxobs,19);
ITM=nan(maxobs,19);
STR=nan(maxobs,19);
Rg1=nan(maxobs,19);
Rg2=nan(maxobs,19);
dPg=nan(maxobs,19);
QUALi=nan(maxobs,19);
Sg1=nan(G,19);
Sg2=nan(G,19);

%loop for data collection
for t2=2:20
    t1=t2-1;
    
    Qt=Q(~isnan(sum([Q(:,t1) Q(:,t2)],2)),[t1 t2]);
    Pt=P(~isnan(sum([Q(:,t1) Q(:,t2)],2)),[t1 t2]);
    Gt=MTX(~isnan(sum([Q(:,t1) Q(:,t2)],2)),2);
    ORGt=MTX(~isnan(sum([Q(:,t1) Q(:,t2)],2)),9);
    ITMt=MTX(~isnan(sum([Q(:,t1) Q(:,t2)],2)),8);
    STRt=MTX(~isnan(sum([Q(:,t1) Q(:,t2)],2)),1);
    Rt_sum_pre=sum(Qt.*Pt,1);
    
    temp1=abs(log(Qt(:,2)./Qt(:,1)));
    temp2=abs(log(Pt(:,2)./Pt(:,1)));
    
    Rt_sum_post=sum(Qt.*Pt,1);
    censor(t1)=100*mean(Rt_sum_post./Rt_sum_pre);
    
    Rt=Qt.*Pt;
    Nt=size(Qt,1);
    
    MUVt=nan(G,2);
    Rt_sec_adj=nan(G,2);
    dpG=nan(G,1);
    for i=1:G;
        Qtsum_temp=nansum(Qt(ismember(Gt,seclist(i)),:),1);
        Rtsum_temp=nansum(Rt(ismember(Gt,seclist(i)),:),1);
        Rt_sec_adj(i,:)=Rtsum_temp;
        MUVt(i,:)=Rtsum_temp./Qtsum_temp;
        Qt_temp=Qt(ismember(Gt,seclist(i)),:);
        Pt_temp=Pt(ismember(Gt,seclist(i)),:);
        [x1,x2,x3,x4,dpG(i,:)]=pinx_fn([Qt_temp Pt_temp],2,0,1);
    end
    St_sec_adj=Rt_sec_adj./repmat(nansum(Rt_sec_adj,1),G,1);
    [I,J]=ismember(Gt,seclist);
    Rt_sec_adj=Rt_sec_adj(J,:);
    dpG=dpG(J,:);
    MUVt=MUVt(J,:);
    QUALt=repmat(nanmean(Pt./MUVt,2),1,1);
    
    Ri1(1:Nt,t1)=Rt(:,1);
    Ri2(1:Nt,t1)=Rt(:,2);
    Pi1(1:Nt,t1)=Pt(:,1);
    Pi2(1:Nt,t1)=Pt(:,2);
    Qi1(1:Nt,t1)=Qt(:,1);
    Qi2(1:Nt,t1)=Qt(:,2);
    GRP(1:Nt,t1)=Gt;
    ORG(1:Nt,t1)=ORGt;
    ITM(1:Nt,t1)=ITMt;
    STR(1:Nt,t1)=STRt;
    Rg1(1:Nt,t1)=Rt_sec_adj(:,1);
    Rg2(1:Nt,t1)=Rt_sec_adj(:,2);
    dPg(1:Nt,t1)=dpG;
    QUALi(1:Nt,t1)=QUALt;
    Sg1(1:G,t1)=St_sec_adj(:,1);
    Sg2(1:G,t1)=St_sec_adj(:,2);
end

%Fix item quality over time
QUALi_v=reshape(QUALi,maxobs*(obs-1),1);
ITM_v=reshape(ITM,maxobs*(obs-1),1);
STR_v=reshape(STR,maxobs*(obs-1),1);
ITM_ID=ITM_v.*STR_v;
itm_list=unique(ITM_ID);
QUALi_v_const=nan(length(QUALi_v),1);
for j=1:length(itm_list)
I=ismember(ITM_ID,itm_list(j));
QUALi_v_const(I)=median(QUALi_v(I));
end
QUALi_const=reshape(QUALi_v_const,maxobs,obs-1);

%HH real consumption expenditures, per capita (from LVA stat office)
d_lnC_qoq=[0.030340818	0.064709312	-0.053387566	0.03875085	0.01089497...
    0.007962849	-0.052184496	0.024548667	-0.00559817	-0.022191826...
    -0.102583712	0.012572078	-0.001515062	0.013720204	-0.027826078...
    0.02424636	0.021329262	0.0195318	-0.040224824];
d_C=repmat(d_lnC_qoq,maxobs,1);


%save regression data
%save ../Data/regdata Ri1 Ri2 Pi1 Pi2 Qi1 Qi2 GRP ORG ITM STR Rg1 Rg2 dPg...
%  QUALi QUALi_const Sg1 Sg2 d_C G seclist