% This code loads estimation results form stata and generates Figures 14-15
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all
load Data/regdata

FS=12;%FontSize
LW=2.5;%LineWidth
tline=2007.25:0.25:2011.0;

%Old baseline from Apr15
M_CES=csvread('..\Stata\data\beta_est_base1.csv');
COVhat_CES=csvread('..\Stata\data\cov_est_base1.csv');
M_NH=csvread('..\Stata\data\\beta_est_base2.csv');
COVhat_NH=csvread('..\Stata\data\cov_est_base2.csv');

%rearrange coeffs estimated by regressions
d_ln_P_ig=log(Pi2./Pi1)-log(dPg);
d_ln_C_lnRELQUAL=log(QUALi_const).*d_C;
if size(M_CES,1)==G,
    beta=[M_CES;nan];%add NaN because matrix format has NaNs
    beta1=[M_NH(:,1);nan];
    beta2=[M_NH(:,2);nan];
else
    beta=[repmat(M_CES,G,1);nan];%add NaN because matrix format has NaNs
    beta1=[repmat(M_NH(:,1),G,1);nan];
    beta2=[repmat(M_NH(:,2),G,1);nan];
end
GRP(isnan(GRP))=99999;%99999 handles NaNs
[I,J]=ismember(GRP,[seclist;99999]);
GRP(GRP==99999)=nan;%revese changes in GRP variable
beta_mtx=beta(J);
beta1_mtx=beta1(J);
beta2_mtx=beta2(J);

%predict changes in expenditure shares
PDCT_CES=beta_mtx.*d_ln_P_ig;
PDCT_NH=beta1_mtx.*d_ln_P_ig+beta2_mtx.*d_ln_C_lnRELQUAL;
PDCT_NH_P=beta1_mtx.*d_ln_P_ig;
PDCT_NH_C=beta2_mtx.*d_ln_C_lnRELQUAL;

%generate expenditure switching decomposition for each t-->t+1
DATATAB=[];
QFmtx_P=zeros(G,20);
QFmtx_C=zeros(G,20);
for t2=2:20
    t1=t2-1;
    
    %actual/predicted expenditure shares
    phi_dta=[Ri1(:,t1)./Rg1(:,t1) Ri2(:,t1)./Rg2(:,t1)];
    phi_mdl_ces=[Ri1(:,t1)./Rg1(:,t1)...
        exp(log(Ri1(:,t1)./Rg1(:,t1))+PDCT_CES(:,t1))];
    phi_mdl_nh=[Ri1(:,t1)./Rg1(:,t1)...
        exp(log(Ri1(:,t1)./Rg1(:,t1))+PDCT_NH(:,t1))];
    phi_mdl_nh_P=[Ri1(:,t1)./Rg1(:,t1)...
        exp(log(Ri1(:,t1)./Rg1(:,t1))+PDCT_NH_P(:,t1))];
    phi_mdl_nh_C=[Ri1(:,t1)./Rg1(:,t1)...
        exp(log(Ri1(:,t1)./Rg1(:,t1))+PDCT_NH_C(:,t1))];    
    
    %predictions for variance calculations
    QF_P=(Ri1(:,t1)./Rg1(:,t1)).*d_ln_P_ig(:,t1);
    QF_C=(Ri1(:,t1)./Rg1(:,t1)).*d_ln_C_lnRELQUAL(:,t1);

    phi_dta_F=nan(G,2);
    phi_mdl_ces_F=nan(G,2);
    phi_mdl_nh_F=nan(G,2);
    Gt=GRP(:,t1);
    ORGt=ORG(:,t1);
    for i=1:G;
        ORGt_temp=ORGt(Gt==seclist(i),:);
        phi_dta_temp=phi_dta(Gt==seclist(i),:);
        phi_mdl_ces_temp=phi_mdl_ces(Gt==seclist(i),:);
        phi_mdl_nh_temp=phi_mdl_nh(Gt==seclist(i),:);
        phi_mdl_nh_P_temp=phi_mdl_nh_P(Gt==seclist(i),:);
        phi_mdl_nh_C_temp=phi_mdl_nh_C(Gt==seclist(i),:);
        
        %QF matrix (GxT-1)
        QFmtx_P(i,t2)=sum(QF_P(Gt==seclist(i),:),1);%initial row empty
        QFmtx_C(i,t2)=sum(QF_C(Gt==seclist(i),:),1);%initial row empty
        
        %data
        phi_dta_F_temp=phi_dta_temp(~ismember(ORGt_temp,[941 101]),:);
        if isempty(phi_dta_F_temp)==1
            phi_dta_F(i,:)=zeros(1,2);
        else
            phi_dta_F_temp2=~isnan(phi_dta_F_temp);
            phi_dta_F(i,:)=nansum(phi_dta_F_temp,1)./max(phi_dta_F_temp2);
        end
        %CES
        phi_mdl_ces_F_temp=phi_mdl_ces_temp(~ismember(ORGt_temp,[941 101]),:);
        if isempty(phi_mdl_ces_F_temp)==1
            phi_mdl_ces_F(i,:)=zeros(1,2);
        else
            phi_mdl_ces_F_temp2=~isnan(phi_mdl_ces_F_temp);
            phi_mdl_ces_F(i,:)=nansum(phi_mdl_ces_F_temp,1)./max(phi_mdl_ces_F_temp2);
        end
        %NH
        phi_mdl_nh_F_temp=phi_mdl_nh_temp(~ismember(ORGt_temp,[941 101]),:);
        if isempty(phi_mdl_nh_F_temp)==1
            phi_mdl_nh_F(i,:)=zeros(1,2);
        else
            phi_mdl_nh_F_temp2=~isnan(phi_mdl_nh_F_temp);
            phi_mdl_nh_F(i,:)=nansum(phi_mdl_nh_F_temp,1)./max(phi_mdl_nh_F_temp2);
        end   
        %NH-price only
        phi_mdl_nh_F_P_temp=phi_mdl_nh_P_temp(~ismember(ORGt_temp,[941 101]),:);
        if isempty(phi_mdl_nh_F_P_temp)==1
            phi_mdl_nh_F_P(i,:)=zeros(1,2);
        else
            phi_mdl_nh_F_P_temp2=~isnan(phi_mdl_nh_F_P_temp);
            phi_mdl_nh_F_P(i,:)=nansum(phi_mdl_nh_F_P_temp,1)./max(phi_mdl_nh_F_P_temp2);
        end 
        %NH-income only
        phi_mdl_nh_F_C_temp=phi_mdl_nh_C_temp(~ismember(ORGt_temp,[941 101]),:);
        if isempty(phi_mdl_nh_F_C_temp)==1
            phi_mdl_nh_F_C(i,:)=zeros(1,2);
        else
            phi_mdl_nh_F_C_temp2=~isnan(phi_mdl_nh_F_C_temp);
            phi_mdl_nh_F_C(i,:)=nansum(phi_mdl_nh_F_C_temp,1)./max(phi_mdl_nh_F_C_temp2);
        end        
        
    end
    
    F_share_dta=nansum(phi_dta_F.*[Sg1(:,t1) Sg2(:,t1)],1);
    F_share_mdl_ces=nansum(phi_mdl_ces_F.*[Sg1(:,t1) Sg2(:,t1)],1);
    F_share_mdl_nh=nansum(phi_mdl_nh_F.*[Sg1(:,t1) Sg2(:,t1)],1);
    
    ALL_dta=F_share_dta(:,2)-F_share_dta(:,1);
    WITHIN_dta=nansum(Sg1(:,t1).*...
        (phi_dta_F(:,2)-phi_dta_F(:,1)),1);
    ACROSS_dta=nansum(phi_dta_F(:,1).*...
        (Sg2(:,t1)-Sg1(:,t1)),1);
    HIGHER_dta=nansum((phi_dta_F(:,2)-phi_dta_F(:,1)).*...
        (Sg2(:,t1)-Sg1(:,t1)),1);    
    
    ALL_mdl_ces=F_share_mdl_ces(:,2)-F_share_mdl_ces(:,1);
    WITHIN_mdl_ces=nansum(Sg1(:,t1).*...
        (phi_mdl_ces_F(:,2)-phi_mdl_ces_F(:,1)),1);
    ACROSS_mdl_ces=nansum(phi_mdl_ces_F(:,1).*...
        (Sg2(:,t1)-Sg1(:,t1)),1);
    HIGHER_mdl_ces=nansum((phi_mdl_ces_F(:,2)-phi_mdl_ces_F(:,1)).*...
        (Sg2(:,t1)-Sg1(:,t1)),1);
    
    ALL_mdl_nh=F_share_mdl_nh(:,2)-F_share_mdl_nh(:,1);
    WITHIN_mdl_nh=nansum(Sg1(:,t1).*...
        (phi_mdl_nh_F(:,2)-phi_mdl_nh_F(:,1)),1);
    ACROSS_mdl_nh=nansum(phi_mdl_nh_F(:,1).*...
        (Sg2(:,t1)-Sg1(:,t1)),1);
    HIGHER_mdl_nh=nansum((phi_mdl_nh_F(:,2)-phi_mdl_nh_F(:,1)).*...
        (Sg2(:,t1)-Sg1(:,t1)),1);
    WITHIN_mdl_nh_P=nansum(Sg1(:,t1).*...
        (phi_mdl_nh_F_P(:,2)-phi_mdl_nh_F_P(:,1)),1);
    WITHIN_mdl_nh_C=nansum(Sg1(:,t1).*...
        (phi_mdl_nh_F_C(:,2)-phi_mdl_nh_F_C(:,1)),1);
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    VAR1=[ALL_dta;ACROSS_dta;WITHIN_dta;HIGHER_dta];
    VAR2=[ALL_mdl_ces;ACROSS_mdl_ces;WITHIN_mdl_ces;HIGHER_mdl_ces];
    VAR3=[ALL_mdl_nh;ACROSS_mdl_nh;WITHIN_mdl_nh;HIGHER_mdl_nh];
    VAR4=[WITHIN_mdl_nh_P;WITHIN_mdl_nh_C];
    VAR=[VAR1;VAR2;VAR3;VAR4];
    DATATAB=[DATATAB VAR];
end

for t=1:16
    DATATAB_mod(:,t)=sum(DATATAB(:,t:t+3),2);
end

%compute 2STDs for error bands 
%generate relevant weights and covariances
Sg1_2G=repmat(Sg1,2,1);%2Gx19
QFmtx=[QFmtx_P;QFmtx_C];%2Gx20
GMA=QFmtx(:,2:20).*Sg1_2G(:,1:19);
COV_CES=zeros(2*G,2*G);
COV_CES(1:G,1:G)=COVhat_CES;
COV_NH=COVhat_NH;

%compute variances
varW_CES=GMA'*COV_CES*GMA;
varW_NH=GMA'*COV_NH*GMA;

for t=4:19
    sum_varW_CES(t-3)=sum(sum(varW_CES(t-3:t,t-3:t)));
    sum_varW_NH(t-3)=sum(sum(varW_NH(t-3:t,t-3:t)));
end

%2*STD error bands
std_CES=sum_varW_CES.^(1/2);
std_NH=sum_varW_NH.^(1/2);
band=1.96;

VAR1=DATATAB_mod(3,:);
VAR2=DATATAB_mod(7,:);
VAR3=DATATAB_mod(11,:);
VAR4=std_CES;
VAR5=std_NH;

figure;
[l,p]=boundedline(tline,VAR2,band*VAR4,'g-.',tline,VAR3,band*VAR5,'r--');
d=plot(tline,VAR1,'b-','LineWidth',LW);
set(l,'LineWidth',LW);
set(l(1,1),'Color',[0 0.498039215803146 0]);
set(gca,'FontSize',FS)
hline(0,'k-')
xlim([2007.25 2011.0])
ylim([-0.025 0.015])
ylabel('Y-o-y change in import expenditure share')
legend([d l'],'Data','CES','Non-homothetic','Location','Southwest')

figure;
plot(tline,DATATAB_mod(11,:),'-',tline,DATATAB_mod(13,:),'-.',...
    tline,DATATAB_mod(14,:),'--','LineWidth',LW);
set(gca,'FontSize',FS)
hline(0,'k-')
xlim([2007.25 2011.0])
ylim([-0.025 0.015])
ylabel('Y-o-y change in import expenditure share')
legend('Total','Price effect','Income effect','Location','SouthWest')