set more off
set matsize 10000

capture log close
log using tableA3, text replace

/*
	Date: September 2016

	Paper: "Income-Induced Expenditure Switching," Bems and di Giovanni (2016)

	Replication of IV pooled coefficient regressions underlying Table A3
	
	Program: 
		
		1. Loads 4 digit prodcode data 
		2. Merges in Estonia dat
		3. Run pooled IV regs based on:
			(a) XR and XR*Quality
			(b) Estoninan prices
*/

*******************************DATA*********************************************

/******************************************
	LOAD DATA AND PREPARE 	  
******************************************/

use 4julian_digit_Q300_P50_rho_nomerge_balticsincl_ner, clear

merge itm_id store_id time using 4julian_digit_Q300_P50_rho_nomerge_balticsincl_ner_EST, keep(pi_EST d_ln_pi_Pg_EST)

* Drop sectors that are not identified 
	
drop if prodcode4==2101  | prodcode4==3043 | prodcode4==3045 | prodcode4==3204|prodcode4==4861

* Drop if only one prodt or itm_id

egen cc1 = count(d_ln_phi), by(prodt)
drop if cc1<2
egen cc2 = count(d_ln_phi), by(itm_id)
drop if cc2<2
drop cc1 cc2

*  Generate quality regressors, linear, quadratic

ge d_ln_qual = ln_relUV_const*d_ln_C
ge d_ln_qual2 = ln_relUV_const*(d_ln_C)^2

* Generate H/F dummy interaction with group-time
	
egen prodtHF = group(prodt dom)

* Generate quality*xrate

ge d_ln_qual_ner = ln_relUV_const*d_ln_ner
foreach X of numlist 1/8{
	ge d_ln_qual_ner_lag`X' = ln_relUV_const*d_ln_ner_lag`X'
}

ge euro = 1 if ctry_code==122|ctry_code==124|ctry_code==132|ctry_code==134| ///
	ctry_code==136|ctry_code==138|ctry_code==172|ctry_code==174|ctry_code==178| ///
	ctry_code==182|ctry_code==184|ctry_code==939|ctry_code==946
		
/******************************************
	FOREIGN ITEMS: PANEL A
******************************************/

/**********************************
  CES: pooled
  
  1. UPC FE only
  2. XR only
  3. XR only for foreign times
  4. EST price only for LVA goods
************************************/

* Column (1)

reghdfe d_ln_phi d_ln_pi_Pg if dom==0 & euro~=1, abs(prodt) cluster(id)
outreg2 using tables/regsIV_ces_pooled.xls, replace excel 2aster dec(3) ctitle("OLS-FOR","base") addstat("Group*time FE", e(K1)-e(M1))

* Column (2)

reghdfe d_ln_phi (d_ln_pi_Pg = d_ln_ner_lag1-d_ln_ner_lag6 d_ln_qual_ner_lag1-d_ln_qual_ner_lag6 ln_relUV_const) if dom==0 & euro~=1, abs(prodt) cluster(id)
outreg2 using tables/regsIV_ces_pooled.xls, append excel 2aster dec(3) ctitle("IV-FOR", "NER") addstat("Group*time FE", e(K1)-e(M1),"Kleibergen-Paap rk LM stat", e(idstat), "Hansen J stat", e(j), "Cragg-Donald F stat" , e(cdf), "Kleibergen-Paap rk Wald F stat", e(widstat))

* Column (3)

reghdfe d_ln_phi d_ln_qual d_ln_pi_Pg if dom==0 & euro~=1, abs(prodt) cluster(id)
outreg2 using tables/regsIV_nh_pooled.xls, replace excel 2aster dec(3) ctitle("OLS-FOR","") addstat("Group*time FE", e(K1)-e(M1))

* Column (4)

reghdfe d_ln_phi d_ln_qual (d_ln_pi_Pg = d_ln_ner_lag1-d_ln_ner_lag6 d_ln_qual_ner_lag1-d_ln_qual_ner_lag6 ln_relUV_const) if dom==0 & euro~=1, abs(prodt) cluster(id)
outreg2 using tables/regsIV_nh_pooled.xls, append excel 2aster dec(3) ctitle("IV-FOR", "NER, NER-QUAL") addstat("Group*time FE", e(K1)-e(M1),"Kleibergen-Paap rk LM stat", e(idstat), "Hansen J stat", e(j), "Cragg-Donald F stat" , e(cdf), "Kleibergen-Paap rk Wald F stat", e(widstat))

/******************************************
	DOMESTIC ITEMS: PANEL B
******************************************/

* Column (1)

reghdfe d_ln_phi d_ln_pi_Pg if ctry_code==941 & d_ln_qual<.04 & d_ln_qual>-.04, abs(prodt) cluster(id)
outreg2 using tables/regsIV_ces_pooled.xls, append excel 2aster dec(3) ctitle("OLS-LVA","") addstat("Group*time FE", e(K1)-e(M1))

* Column (2)

reghdfe d_ln_phi (d_ln_pi_Pg = d_ln_pi_Pg_EST) if ctry_code==941 & d_ln_qual<.04 & d_ln_qual>-.04, abs(prodt) cluster(id)
outreg2 using tables/regsIV_ces_pooled.xls, append excel 2aster dec(3) ctitle("IV-LVA", "P_EST") addstat("Group*time FE", e(K1)-e(M1),"Kleibergen-Paap rk LM stat", e(idstat), "Hansen J stat", e(j), "Cragg-Donald F stat" , e(cdf), "Kleibergen-Paap rk Wald F stat", e(widstat))

* Column (3)

reghdfe d_ln_phi d_ln_qual d_ln_pi_Pg if ctry_code==941 & d_ln_qual<.04 & d_ln_qual>-.04, abs(prodt) cluster(id)
outreg2 using tables/regsIV_nh_pooled.xls, append excel 2aster dec(3) ctitle("OLS-LVA","") addstat("Group*time FE", e(K1)-e(M1))

* Column (4)

reghdfe d_ln_phi d_ln_qual (d_ln_pi_Pg = d_ln_pi_Pg_EST) if ctry_code==941 & d_ln_qual<.04 & d_ln_qual>-.04, abs(prodt) cluster(id)
outreg2 using tables/regsIV_nh_pooled.xls, append excel 2aster dec(3) ctitle("IV-LVA", "P_EST") addstat("Group*time FE", e(K1)-e(M1),"Kleibergen-Paap rk LM stat", e(idstat), "Hansen J stat", e(j), "Cragg-Donald F stat" , e(cdf), "Kleibergen-Paap rk Wald F stat", e(widstat))

log close



