set more off
set matsize 10000

capture log close
log using tableA5, text replace

/*
	Date: September 2016

	Paper: "Income-Induced Expenditure Switching," Bems and di Giovanni (2016)

	Replication of predicted expenditure switching underlying Table A5	
	
	Program: 
	
		1. Run baseline OLS and XR-QUAL IV regs 
		2. Compute predicted share given data
*/

/******************************************
	LOAD DATA AND PREPARE 	  
******************************************/

use 4julian_digit_Q300_P50_rho_nomerge_balticsincl_ner, clear

merge itm_id store_id time using 4julian_digit_Q300_P50_rho_nomerge_balticsincl_ner_EST, keep(pi_EST d_ln_pi_Pg_EST)

* Drop sectors that are not identified 

drop if prodcode4==2101  | prodcode4==3043 | prodcode4==3045 | prodcode4==3204|prodcode4==4861

* Drop if only one prodt or itm_id

egen cc1 = count(d_ln_phi), by(prodt)
drop if cc1<2
egen cc2 = count(d_ln_phi), by(itm_id)
drop if cc2<2
drop cc1 cc2

*  Generate quality regressors, linear, quadratic

ge d_ln_qual = ln_relUV_const*d_ln_C
ge d_ln_qual2 = ln_relUV_const*(d_ln_C)^2

* Generate H/F dummy interaction with group-time
	
egen prodtHF = group(prodt dom)

* Generate quality*xrate

ge d_ln_qual_ner = ln_relUV_const*d_ln_ner
foreach X of numlist 1/8{
	ge d_ln_qual_ner_lag`X' = ln_relUV_const*d_ln_ner_lag`X'
}

ge euro = 1 if ctry_code==122|ctry_code==124|ctry_code==132|ctry_code==134| ///
	ctry_code==136|ctry_code==138|ctry_code==172|ctry_code==174|ctry_code==178| ///
	ctry_code==182|ctry_code==184|ctry_code==939|ctry_code==946
	
* Calculated from data and fed in manually as local variables

local dp = 0.004360865
local dC = -0.133556368
local pbar = 0.25

/******************************************
	OLS: PANEL A
******************************************/

reghdfe d_ln_phi d_ln_pi_Pg d_ln_qual, abs(prodt) cluster(id)
lincom d_ln_pi_Pg*`dp'
lincom  d_ln_qual*`dC'*`pbar'
lincom d_ln_pi_Pg*`dp'+d_ln_qual*`dC'*`pbar'

nlcom (_b[d_ln_pi_Pg]*`dp')/(_b[d_ln_pi_Pg]*`dp'+_b[d_ln_qual]*`dC'*`pbar')
nlcom (_b[d_ln_qual]*`dC'*`pbar')/(_b[d_ln_pi_Pg]*`dp'+_b[d_ln_qual]*`dC'*`pbar')

/******************************************
	IV NER & NER*QUAL: PANEL B
******************************************/

reghdfe d_ln_phi d_ln_qual (d_ln_pi_Pg = d_ln_ner_lag1-d_ln_ner_lag6 d_ln_qual_ner_lag1-d_ln_qual_ner_lag6 ln_relUV_const)  if dom==0 & euro~=1, abs(prodt) cluster(id)
lincom d_ln_pi_Pg*`dp'
lincom  d_ln_qual*`dC'*`pbar'
lincom d_ln_pi_Pg*`dp'+d_ln_qual*`dC'*`pbar'

nlcom (_b[d_ln_pi_Pg]*`dp')/(_b[d_ln_pi_Pg]*`dp'+_b[d_ln_qual]*`dC'*`pbar')
nlcom (_b[d_ln_qual]*`dC'*`pbar')/(_b[d_ln_pi_Pg]*`dp'+_b[d_ln_qual]*`dC'*`pbar')

log close



